\name{AIC-methods}
\docType{methods}
\title{Methods for Function AIC}
\alias{AIC,flexmix-method}
\description{Compute the Akaike Information Criterion.}
\section{Methods}{
  \describe{
    \item{object = flexmix:}{Compute the AIC of an \code{flexmix} object}
  }
}
\keyword{methods}

\eof
\name{BIC-methods}
\docType{methods}
\title{Methods for Function BIC}
\alias{BIC,flexmix-method}
\description{Compute the Bayesian Information Criterion.}
\section{Methods}{
  \describe{
    \item{object = flexmix:}{Compute the BIC of an \code{flexmix} object}
  }
}
\keyword{methods}

\eof
\name{ExNPreg}
\alias{ExNPreg}
\alias{NPreg}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Artificial Example for Normal and Poisson Regression}
\description{
  A simple artificial regression example with 2 latent classes, one
  independent variable
  (uniform on \eqn{[0,10]}), and two dependent variables with Gaussian and
  Poisson distribution, respectively.
}
\usage{
ExNPreg(n)
data(NPreg)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{n}{Number of observations per latent class.}
}
\details{
  The \code{NPreg} data frame can be re-created by \code{ExNPreg(100)}
  using \code{set.seed(2602)}, it has been saved as a data set for
  simplicity of examples only.
}
\examples{
data(NPreg)
plot(yn~x, data=NPreg, col=class)
plot(yp~x, data=NPreg, col=class)
}
\keyword{datasets}

\eof
\name{ExNclus}
\alias{ExNclus}
\alias{Nclus}
\title{Artificial Example for Normal Clustering}
\description{
  A simple artificial regression example with 4 latent classes, all of
  them having a Gaussian distribution. See the function definition for
  true means and covariances.
}
\usage{
ExNclus(n)
data(Nclus)
}
\arguments{
  \item{n}{Number of observations in the two small latent classes.}
}
\details{
  The \code{Nclus} data set can be re-created by \code{ExNclus(100)}
  using \code{set.seed(2602)}, it has been saved as a data set for
  simplicity of examples only.
}
\examples{
data(Nclus)
require("MASS")
eqscplot(Nclus, col=rep(1:4, c(100, 100, 150, 200)))
}
\keyword{datasets}

\eof
\name{FLXcomponent-class}
\docType{class}
\alias{FLXcomponent-class}
\alias{show,FLXcomponent-method}
\title{Class "FLXcomponent"}
\description{A fitted component of a \code{\link{flexmix}} model.}
\section{Objects from the Class}{
Objects can be created by calls of the form \code{new("FLXcomponent", ...)}.
}
\section{Slots}{
  \describe{
    \item{\code{df}:}{Number of paramters used by the component.}
    \item{\code{logLik}:}{Function computing the log-likelihood of
      observations.}
    \item{\code{parameters}:}{List with model parameters.}
    \item{\code{predict}:}{Function predicting response for new data.}
  }
}
\author{Friedrich Leisch}
\keyword{classes}

\eof
\name{FLXcontrol-class}
\docType{class}
\alias{FLXcontrol-class}
\alias{coerce,list,FLXcontrol-method}
\alias{coerce,NULL,FLXcontrol-method}
\title{Class "FLXcontrol"}
\description{Hyperparameters for the EM algorithm.}
\section{Objects from the Class}{
Objects can be created by calls of the form \code{new("FLXcontrol",
  ...)}. In addition, named lists can be coerced to \code{FLXcontrol}
objects, names are completed if unique (see examples).
}
\section{Slots}{
  \describe{
    \item{\code{iter.max}:}{Maximum number of iterations.}
    \item{\code{minprior}:}{Minimum prior probability of clusters,
      components falling below this threshold are removed during the
      iteration.}
    \item{\code{tolerance}:}{The EM algorithm is stopped when the
      (relative) change of log-likelood is smaller than \code{tolerance}.}
    \item{\code{verbose}:}{If a positive integer, then the
      log-likelihood is reported every \code{verbose} iterations. If 0,
      no output is generated during model fitting.}
    \item{\code{classify}:}{Character string, one of \code{"auto"},
      \code{"weighted"}, \code{"hard"}, \code{"random"}.}
  }
}

\author{Friedrich Leisch}
\keyword{classes}
\examples{
mycont = list(iter=200, tol=0.001, class="r")
as(mycont, "FLXcontrol")
}

\eof
\name{FLXfit}
\alias{FLXfit}
\title{Fitter Function for FlexMix Models}
\description{
  This is the basic computing engine called by \code{\link{flexmix}}, it
  should usually not be used directly.
}
\usage{
FLXfit(k = NULL, cluster = NULL, model, control, group)
}
\arguments{
  \item{k}{Number of clusters (not needed if \code{cluster} is specified).}
  \item{cluster}{Initial cluster assignments of observations at the
    start of the EM algorithm (default is random assignment into \code{k}
    clusters).}
  \item{model}{List of \code{FLXmodel} objects.}
  \item{control}{Object of class \code{FLXcontrol}.}
  \item{group}{Factor with optional grouping of observations.}
}
\value{
  Returns an object of class \code{flexmix}.
}
\author{Friedrich Leisch}
\seealso{\code{\link{flexmix}}, \code{\link{flexmix-class}}}
\keyword{regression}
\keyword{cluster}

\eof
\name{FLXglm}
\alias{FLXglm}
\title{FlexMix Interface to Generalized Linear Models}
\description{
  This is the main driver for FlexMix interfacing the \code{\link{glm}}
  family of models.
}
\usage{
FLXglm(formula = . ~ ., family = c("gaussian", "binomial", "poisson", "Gamma"))
}
\arguments{
  \item{formula}{A formula which is interpreted relative to the formula
    specified in the call to \code{\link{flexmix}} using
    \code{\link{update.formula}}. Default is to use the original
    \code{\link{flexmix}} model
    formula.}
  \item{family}{A character string naming a \code{\link{glm}}
    family function.}
}
\details{
  See \code{\link{flexmix}} for examples.
}
\value{
  Returns an object of class \code{FLXmodel}.
}
\author{Friedrich Leisch}
\references{
  Friedrich Leisch. FlexMix: A general framework for finite mixture
  models and latent class regression in R. Journal of Statistical
  Software, 11(8), 2004. http://www.jstatsoft.org/v11/i08/
}
\seealso{\code{\link{flexmix}}, \code{\link{glm}}}
\keyword{regression}
\keyword{models}

\eof
\name{FLXmclust}
\alias{FLXmclust}
\alias{plotEll}
\title{FlexMix Clustering Demo Driver}
\description{
  This is a demo driver for \code{\link{flexmix}} implementing
  model-based clustering of Gaussian data. 
}
\usage{
FLXmclust(formula = . ~ ., diagonal = TRUE)
plotEll(object, data, ...)
}
\arguments{
  \item{formula}{A formula which is interpreted relative to the formula
    specified in the call to \code{\link{flexmix}} using
    \code{\link{update.formula}}. Only the left-hand side (response) of
    the formula is used. Default is to use the original
    \code{\link{flexmix}} model
    formula.}
  \item{diagonal}{If \code{TRUE}, then the covariance matrix of the
    components is restricted to diagonal matrices.}
  \item{object}{An object of class \code{flexmix} using \code{FLXmclust}
    model.}
  \item{data}{The data that were clustered.}
  \item{\dots}{Passed to \code{\link[MASS]{eqscplot}}.}
}
\details{
  This is meant as a demo for FlexMix driver programming, use package
  \pkg{mclust} for real applications. 
}
\value{
  \code{FLXmclust} returns an object of class \code{FLXmodel}.
}
\author{Friedrich Leisch}
\references{
  Friedrich Leisch. FlexMix: A general framework for finite mixture
  models and latent class regression in R. Journal of Statistical
  Software, 11(8), 2004. http://www.jstatsoft.org/v11/i08/
}
\seealso{\code{\link{flexmix}}}
\keyword{cluster}
\examples{
data(Nclus)

require("MASS")
eqscplot(Nclus)

## This model is wrong (one component has a non-diagonal cov matrix)
ex1 <- flexmix(Nclus~1, k=4, model=FLXmclust())
print(ex1)
plotEll(ex1, Nclus)

## True model, wrong number of components
ex2 <- flexmix(Nclus~1, k=6, model=FLXmclust(diag=FALSE))  
print(ex2)

plotEll(ex2, Nclus)

parameters(ex2, component=1)
}

\eof
\name{FLXmodel-class}
\docType{class}
\alias{FLXmodel-class}
\alias{show,FLXmodel-method}
\title{Class "FLXmodel"}
\description{FlexMix model specification.}
\section{Objects from the Class}{
  Objects can be created by calls of the form \code{new("FLXmodel", ...)},
  typically inside driver functions like \code{\link{FLXglm}} or
  \code{\link{FLXmclust}}. 
}
\section{Slots}{
  \describe{
    \item{\code{fit}:}{Function returning an \code{FLXmodel} object.}
    \item{\code{weighted}:}{Logical indicating whether \code{fit} can do
    weighted likelihood maximization.}
    \item{\code{name}:}{Character string used in print methods.}
    \item{\code{formula}:}{Formula describing the model.}
    \item{\code{x}:}{Model matrix.}
    \item{\code{y}:}{Model response.}
  }
}

\author{Friedrich Leisch}
\keyword{classes}

\eof
\name{KLdiv}
\alias{KLdiv}
\alias{KLdiv-methods}
\alias{KLdiv,matrix-method}
\alias{KLdiv,flexmix-method}
\title{Kullbach Leibler Divergence}
\description{
  Estimate the Kullbach Leibler divergence of several distributions.}
\usage{
KLdiv(object, ...)
\S4method{KLdiv}{matrix}(object, eps=1e-4, ...)
}
\arguments{
  \item{object}{see Methods section below}
  \item{eps}{probabilities below this treshold are discarded for
    numerical stability}
  \item{...}{Passed to the matrix method.}
}
\section{Methods}{
  \describe{
    \item{object = "matrix":}{Takes as input a matrix of
      density values with one row per observation and one column per
      distribution.}
    \item{object = "flexmix":}{Returns the Kullbach Leibler divergence
      of the mixture components.}
}}
\details{
  Estimates \deqn{\int f(x) (\log f(x) - \log g(x)) dx}
  for distributions with densities \eqn{f()} and \eqn{g()}.
}
\value{
  A matrix of of KL divergences where the rows correspond to using the
  respective distribution as \eqn{f()} in the formula above.
}
\keyword{methods}
\author{Friedrich Leisch}
\references{
  Friedrich Leisch. Exploring the structure of mixture model
  components. In Jaromir Antoch, editor, Compstat 2004 - Proceedings in
  Computational Statistics, pages 1405-1412. Physika Verlag, Heidelberg,
  Germany, 2004. ISBN 3-7908-1554-3.
}
\examples{
x = (1:100)/100
## Gaussian and Student t are much closer to each other than
## to the uniform:
KLdiv(cbind(u=dunif(x), n=dnorm(x), t=dt(x, df=10)))
}

\eof
\name{flexmix-class}
\docType{class}
\alias{flexmix-class}
\title{Class "flexmix"}
\description{A fitted \code{\link{flexmix}} model.}
\section{Objects from the Class}{
Objects are typically created by calling function \code{\link{flexmix}}.
}
\section{Slots}{
  \describe{
    \item{\code{model}:}{List of \code{FLXmodel} objects.}
    \item{\code{prior}:}{Numeric vector with prior probabilities of clusters.}
    \item{\code{posterior}:}{Named list with elements \code{scaled}
      and \code{unscaled}, both matrices with one row per observation
      and one column per cluster.}
    \item{\code{iter}:}{Number of EM
      iterations.}
    \item{\code{k}:}{Number of clusters.}
    \item{\code{cluster}:}{Cluster assignments of observations.}
    \item{\code{size}:}{Cluster sizes.}
    \item{\code{logLik}:}{Log-likelihood at EM convergence.}
    \item{\code{df}:}{Total number of
      parameters of the model.}
    \item{\code{components}:}{List describing
      the fitted components using \code{FLXcomponent} objects.}
    \item{\code{formula}:}{Object of class \code{"formula"}.}
    \item{\code{control}:}{Object of class \code{"FLXcontrol"}.}
    \item{\code{call}:}{The function call
      used to create the object.}
    \item{\code{group}:}{Object of class \code{"factor"}.}
    \item{\code{converged}}{Logical, \code{TRUE} if EM algorithm converged.}
  }
}
\author{Friedrich Leisch}
\keyword{classes}

\eof
\name{flexmix-internal}
\alias{FLXglmmodel-class}
\alias{FLXrefit-class}
\alias{FLXrefitglm-class}
\alias{summary.flexmix-class}
\title{Internal FlexMix functions}
\description{
  Internal flexmix functions, methods and classes.
}
\details{
  These are not to be called by the user.
}
\keyword{internal}

\eof
\name{flexmix}
\alias{flexmix}
\alias{flexmix,formula,ANY,ANY,ANY,missing-method}
\alias{flexmix,formula,ANY,ANY,ANY,list-method}
\alias{flexmix,formula,ANY,ANY,ANY,FLXmodel-method}
\alias{parameters}
\alias{parameters,flexmix-method}
\alias{predict,flexmix-method}
\alias{show,flexmix-method}
\alias{summary,flexmix-method}
\alias{show,summary.flexmix-method}
\title{Flexible Mixture Modeling}
\description{
  FlexMix implements a general framework for finite
  mixtures of regression models. Parameter estimation is performed using
  the EM algorithm: the E-step is implemented by \code{flexmix}, while
  the user can specify the M-step.
}
\usage{
flexmix(formula, data = list(), k = NULL, cluster = NULL,
        model=NULL, control = NULL)
\S4method{summary}{flexmix}(object, eps=1e-4, ...)
}
\arguments{
  \item{formula}{A symbolic description of the model to be fit. The
    general form is \code{y~x|g} where \code{y} is the response,
    \code{x} the set of predictors and \code{g} an optional grouping
    factor for repeated measurements.}
  \item{data}{An optional data frame containing the variables in the model.}
  \item{k}{Number of clusters (not needed if \code{cluster} is specified).}
  \item{cluster}{Factor or integer vector with the initial cluster
    assignments of observations at the 
    start of the EM algorithm (default is random assignment into \code{k}
    clusters).}
  \item{model}{Object of \code{FLXmodel} of list of \code{FLXmodel}
    objects. Default is the object returned by calling
    \code{\link{FLXglm}()}.}
  \item{control}{Object of class \code{FLXcontrol} or a named list.}
  \item{object}{Object of class \code{flexmix}.}
  \item{eps}{Probabilities below this treshold are treated as zero in the
    summary method.}
  \item{\dots}{Currently not used.}
}
\details{
  FlexMix models are described by objects of class \code{FLXmodel},
  which in turn are created by driver functions like
  \code{\link{FLXglm}} or \code{\link{FLXmclust}}. Multivariate
  responses with independent components can be specified using a
  list of \code{FLXmodel} objects.

  The \code{summary} method lists for each component the prior
  probability, the number of observations assigned to the corresponding
  cluster, the number of observations with a posterior probability
  larger than \code{eps} and the ratio of the latter two numbers (which
  indicates how separated the cluster is from the others).
}
\value{
  Returns an object of class \code{flexmix}.
}
\author{Friedrich Leisch}
\references{
  Friedrich Leisch. FlexMix: A general framework for finite mixture
  models and latent class regression in R. Journal of Statistical
  Software, 11(8), 2004. http://www.jstatsoft.org/v11/i08/
}
\keyword{regression}
\keyword{cluster}
\examples{

data(NPreg)

## mixture of two linear regression models. Note that control parameters
## can be specified as named list and abbreviated if unique.
ex1 <- flexmix(yn~x+I(x^2), data=NPreg, k=2,
                   control=list(verb=5, iter=100))

ex1
summary(ex1)
plot(ex1)

## now we fit a model with one Gaussian response and one Poisson
## response. Note that the formulas inside the call to FLXglm are
## relative to the overall model formula.
ex2 <- flexmix(yn~x, data=NPreg, k=2,
               model=list(FLXglm(yn~.+I(x^2)), 
                          FLXglm(yp~., family="poisson")))
plot(ex2)

ex2
table(ex2@cluster, NPreg$class)

## for Gaussian responses we get coefficients and standard deviation
parameters(ex2, component=1, model=1)

## for Poisson response we get only coefficients
parameters(ex2, component=1, model=2)

## fitting a model only to the Poisson response is of course
## done like this
ex3 <- flexmix(yp~x, data=NPreg, k=2, model=FLXglm(family="poisson"))

## if observations are grouped, i.e., we have several observations per
## individual, fitting is usually much faster:
ex4 <- flexmix(yp~x|id1, data=NPreg, k=2, model=FLXglm(family="poisson"))
}


\eof
\name{logLik-methods}
\docType{methods}
\title{Methods for Function logLik in Package `flexmix'}
\alias{logLik,flexmix-method}
\description{Evaluate the log-likelihood.  This function is defined as
  an S4 generic in the \code{stats4} package.}
\section{Methods}{
  \describe{
    \item{object = flexmix}{Evaluate the log-likelihood of an
      \code{flexmix} object}
  }
}
\keyword{methods}

\eof
\name{plot-methods}
\docType{methods}
\alias{plot-methods}
\alias{plot,flexmix,missing-method}
\title{Rootogram of Posterior Probabilities}
\description{
  The \code{plot} method for \code{\link{flexmix-class}} objects gives a
  rootogram or histogram of the posterior probabilities.
  }
}
\usage{
\S4method{plot}{flexmix,missing}(x, y, mark=NULL, markcol="red",
  eps=1e-4, root=TRUE, ylim=TRUE, main=NULL, mfrow=NULL, ...)
}
\arguments{
  \item{x}{an object of class \code{"flexmix"}}
  \item{y}{not used}
  \item{mark}{integer, mark posteriors of this component}
  \item{markcol}{color used for marking components}
  \item{eps}{posteriors smaller than \code{eps} are ignored}
  \item{root}{if \code{TRUE}, a rootogram of the posterior probabilities
    is drawn, otherwise a standard historgram}
  \item{ylim}{A logical value or a numeric vector of length n2. If
    \code{TRUE}, the y axes of all rootograms are aligned
    to have the same limits, if \code{FALSE} each y axis is scaled
    separately. If a numeric vector is specified it is used as usual.}
  \item{main}{main title of the plot}
  \item{mfrow}{layout of the plot}
  \item{...}{further graphical parameters}
}
\details{
  For each mixture component a rootogram or histogram of the posterior
  probabilities of all observations is 
  drawn. Rootograms are very similar to histograms, the only difference
  is that the height of the bars correspond to square roots of counts
  rather than the counts themselves, hence low counts are more
  visible and peaks less emphasized.

  Usually in each component a lot of observations have posteriors
  close to zero, resulting in a high count for the corresponing
  bin in the rootogram which obscures the information in the other
  bins. To avoid this problem, all probabilities with a posterior below
  \code{eps} are ignored.

  A peak at probability one indicates that a mixture component is well
  seperated from the other components, while no peak at one and/or
  significant mass in the middle of the unit interval indicates overlap
  with other components.
}
\references{
  Friedrich Leisch. FlexMix: A general framework for finite mixture
  models and latent class regression in R. Journal of Statistical
  Software, 11(8), 2004. http://www.jstatsoft.org/v11/i08/

  Jeremy Tantrum, Alejandro Murua and Werner Stuetzle. Assessment and
  pruning of hierarchical model based clustering. Proceedings of the
  9th ACM SIGKDD international conference on Knowledge Discovery and
  Data Mining, pages 197-205. ACM Press, New York, NY, USA, 2003.

  Friedrich Leisch. Exploring the structure of mixture model
  components. In Jaromir Antoch, editor, Compstat 2004 - Proceedings in
  Computational Statistics, pages 1405-1412. Physika Verlag, Heidelberg,
  Germany, 2004. ISBN 3-7908-1554-3.
}
\author{Friedrich Leisch}
\keyword{methods}
\keyword{hplot}

\eof
\name{refit}
\alias{refit}
\alias{refit-methods}
\alias{refit,flexmix-method}
\alias{refit,FLXglmmodel-method}
\alias{show,FLXrefit-method}
\alias{summary,FLXrefit-method}
\alias{summary,FLXrefitglm-method}
\title{Refit a Fitted Model}
\description{
  Refits an estimated flexmix model to obtain additional information
  like coefficient significance p-values for GLM regression.}
}
\usage{
\S4method{refit}{flexmix}(object, model=1, ...)
}
\arguments{
  \item{object}{an object of class \code{"flexmix"}}
  \item{model}{The model (for a multivariate response) that shall be
    refitted.}
  \item{\dots}{currently not used}
}
\details{
  Currently there is only a \code{refit} method for \code{FLXglm}
  models, which in combination with the \code{summary} method can be
  used to obtain the usual tests for significance of coefficients. Note
  that the tests are valid only if \code{flexmix} returned the maximum
  likelihood estimator of the parameters.
}
\keyword{methods}
\author{Friedrich Leisch}
\references{
  Friedrich Leisch. FlexMix: A general framework for finite mixture
  models and latent class regression in R. Journal of Statistical
  Software, 11(8), 2004. http://www.jstatsoft.org/v11/i08/
}
\examples{
data(NPreg)
ex1 <- flexmix(yn~x+I(x^2), data=NPreg, k=2)
ex1r <- refit(ex1)

## in one component all coefficients should be highly significant,
## in the other component only the linear term
summary(ex1r)
}


\eof
\name{stepFlexmix}
\alias{stepFlexmix}
\title{Run FlexMix Repeatedly}
\description{
  Runs flexmix repeatedly for different numbers of components and return
  the maximum likelihood solution for each.}
}
\usage{
stepFlexmix(..., K=NULL, nrep=3,
            compare=c("logLik", "BIC", "AIC"), verbose=TRUE)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{\dots}{passed to \code{\link{flexmix}}}
  \item{K}{A vector of integers passed in turn to the \code{k} argument
    of \code{\link{flexmix}}}
  \item{nrep}{For each value of \code{k} run \code{\link{flexmix}}
    \code{nrep} times and keep only the solution with maximum
    likelihood.}
  \item{compare}{Goodness of fit measure used to select the best model,
    one of \code{"logLik"}, \code{"BIC"} or \code{"AIC"}.}
  \item{verbose}{If \code{TRUE}, show progress information during
    computations.}
}
\value{
  A list of objects of class \code{"flexmix"} if \code{length(K)>1},
  else directly an object of class \code{"flexmix"}.
}
\author{Friedrich Leisch}
\references{
  Friedrich Leisch. FlexMix: A general framework for finite mixture
  models and latent class regression in R. Journal of Statistical
  Software, 11(8), 2004. http://www.jstatsoft.org/v11/i08/
}
\examples{
data(NPreg)

## try 5 times for k=2
ex1 <- stepFlexmix(yn~x+I(x^2), data=NPreg, K=2, nrep=5)
ex1

## now for k=2,3,4,5
## low nrep to have reasonable execution time of example
## even on slow systems
ex2 <- stepFlexmix(yn~x+I(x^2), data=NPreg, K=2:5, nrep=2)
ex2
sapply(ex2, logLik)

## model selection:
sapply(ex2, AIC)
sapply(ex2, BIC)
}
\keyword{cluster}% at least one, from doc/KEYWORDS
\keyword{regression}% __ONLY ONE__ keyword per line

\eof
